#ifndef __KERNELMANAGERCONTOUR__
#define __KERNELMANAGERCONTOUR__



//------------------------------------------------------------------------------------------------------------
// Includes
//------------------------------------------------------------------------------------------------------------
//#include "ImageSourceThing.h"
//#include "ImageSectionThing.h"
//#include "AxeThing.h"
//#include "ContourThing.h"
#include "OutlineModelManager.h"
#include "OutlineModelBuilder.h"
#include "time.h"

#include "ContourPropagation.h"

#include "manualContourModel.h"
#include "manualContourModelCircle.h"
#include "manualContourModelLine.h"
#include "manualContourModelRoi.h"
#include "manualContourModelPolygon.h"

#include <vtkImageChangeInformation.h>

class KernelManagerContour{

//------------------------------------------------------------------------------------------------------------
// Constructors & Destructors
//------------------------------------------------------------------------------------------------------------
public:

	/**
	** With this constructor the setVectImages and initialize environment must be called
	**/
	KernelManagerContour();
	/**
	**	If images are available before the construction of the kernelManager this method should be used
	**	it sets the vector images and initializes the environment
	**/
	KernelManagerContour(std::vector<vtkImageData*> images,std::string datadir,std::string tmpdir);
	~KernelManagerContour();

	std::vector<vtkImageData*> getVectImages();
	void setVectImages(std::vector<vtkImageData*> vectimg);

	/**
	**	This method returns the source of the image data selected by the user.
	*/
	vtkImageData* getSourceImage();

	

	void initializeEnvironment(std::string datadir);


	/**
	**	This methods connect the event in the class interfNewContourMenu with the world of the appli
	**/	

	std::string createOutline(manualBaseModel * manModelContour,std::vector<int> instantVector);
	/////////////////////////////////

	std::string intToString(int num);

	std::vector<std::string> GetLstNameThingsStatic();

	void SaveThingName(FILE* pFile, FILE *pFileData, std::string name );

	std::vector<std::string> GetLstNameThings();

	bool IsPartOfStaticList(std::string keyName );

	void deleteCModel(std::string theKeyName);

	void removeAllOutlines();

	//void setInstance(theInstant);

	std::vector<NameWrapper *> getActualInstantOutlines();

	int getNamesWrappingSize();

	std::string getNameWrapping(int i);

	void setInstant(Instant* theInstant);
	void setInstant(std::vector<int> vectInstant);
	std::string createCopyContourOf ( std::string anExistingKName, std::vector<int> &instantNoTouchData);
	
	Instant * getCurrentInstant();

	manualBaseModel* getOutlineByKeyName(std::string cloneName);

	bool onRedo(std::string& filename);

	bool onUndo(std::string& filename);

	bool onUndoSaveFile(std::string& filename);

	std::string saveState();

	void changeContourOfManager(std::string keyName, Instant *instant);

	void resetAppend();

	std::string onSpreadAdd( std::vector<double> *vecX, std::vector<double> *vecY, std::vector<double> *vecZ, std::vector<int> instants);

	void getMaxMinZ(double *minZ,double *maxZ);

	manualBaseModel* GetPoints(int z,int type, std::vector<double>* vecCtrlPointX,std::vector<double>* vecCtrlPointY,std::vector<double>* vecCtrlPointZ, std::string& theName,int typeofcontour, std::vector<int> tempVector);

	//
	// Method which creates the model associated with the type in parameter. The possible contour types are:
	// 0-spline
	// 1-spline
	// 2-rectangle
	// 3-circle
	// 4-BullEye
	// 5-BullEyeSector
	// 6-Line
	// 7-Points
	// NOTE: The view and the controler are created in the wxVtkBaseView_SceneManager class, configureViewControlTo method
	// @param typeContour - int
	// @return manualBaseModel - Model created based on the type
	manualBaseModel* factoryManualContourModel(int typeContour);

	void CalculeSplinePropagation();

	std::vector<std::string> getOutlinesNameAtInstant(std::vector<int> tempvector);

	std::vector<ContourThing**> getOutlinesAtInstant(Instant* instant );

	std::vector<manualBaseModel*> ExploseEachModel( std::vector<manualBaseModel*> lstManConMod );

	
	void getConceptsInformation(std::vector<std::string>& conceptNameVect, std::vector<int>& conceptSizeVect);

	vtkImageData* getImageAtInstant(std::vector<int> inst);
	
//------------------------------------------------------------------------------------------------------------
// Constants
//------------------------------------------------------------------------------------------------------------

	void setCurrentFileName(std::string filenam);
	std::string getCurrentFileName();
private: 	
//------------------------------------------------------------------------------------------------------------
// Attributes
//------------------------------------------------------------------------------------------------------------
	std::vector<vtkImageData*> vectimages;

	ImageSourceThing		* imageSource;

	//Instant * _actualInstant;
//Temporary attribute should be removed
	OutlineModelManager		* modelManager;

	std::string filename;

	int inredo;
	int inundo;
	int _currentIndex;
	std::string	stundoredo;

	ContourPropagation* _contourPropagation;

	bool isInitContourPropagation();

	OutlineModelManager* getOutlineModelManager();
};
#endif
